@@ -3,14 +3,14 @@
 
 /*---
 info: Compound Assignment Operator calls PutValue(lref, v)
-es5id: S11.13.2_A5.7_T2
+es5id: S11.13.2_A5.9_T2
 description: >
     Evaluating LeftHandSideExpression lref returns Reference type; Reference
     base value is an environment record and environment record kind is
     object environment record. PutValue(lref, v) uses the initially
     created Reference even if the environment binding is no longer present.
     Binding in surrounding global environment record is not changed.
-    Check operator is "x >>= y".
+    Check operator is "x &= y".
 flags: [noStrict]
 ---*/
 
@@ -18,16 +18,16 @@ var x = 0;
 var scope = {
   get x() {
     delete this.x;
-    return 16;
+    return 5;
   }
 };
 
 with (scope) {
-  x >>= 3;
+  x &= 3;
 }
 
-if (scope.x !== 2) {
-  $ERROR('#1: scope.x === 2. Actual: ' + (scope.x));
+if (scope.x !== 1) {
+  $ERROR('#1: scope.x === 1. Actual: ' + (scope.x));
 }
 if (x !== 0) {
   $ERROR('#2: x === 0. Actual: ' + (x));
